#!/usr/bin/perl -w

##############################################################################
#
#	cost-et.pl	-	COST-ET tool main file
#	
#	This file is part of the COST-ET tool written by 
#	Marios Kleanthous, Damien Hardy, Isidoros Sideris and Yiannakis Sazeides
#	University of Cyprus
#	The research leading to this tool is supported by the European Commission
#	FP7 project ”Energy-conscious 3D Server-on-Chip for Green Cloud
#	Services (Project No:247779 ”EuroCloud”)”
#
#	This source file is distributed "as is" in the hope that it will be useful.
#	The tool comes with no warranty, and no author or distributor accepts any
#	responsability for the consequences of its use.
#
#	Everyone is granted permission to copy, modify and redistribute
#	this tool set under the following conditions:
#
#		This source code is distributed for non-commercial use only.
#		Please contact the maintainer for restrictions applying to
#		commercial use.
#
#		Permission is granted to anyone to make or distribute copies
#		of this source code, either as received or modified, in any
#		medium, provided that all copyright notices, permission and
#		nonwarranty notices are preserved, and that the distributor
#		grants the recipient permission for further redistribution as
#		permitted by this document.
#
#		Permission is granted to distribute this file in compiled
#		or executable form under the same conditions that apply for
#		source code, provided that either:
#
#		A.	it is accompanied by the corresponding machine-readable
#			source code,
#		B.	it is accompanied by a written offer, with no time limit,
#			to give anyone a machine-readable copy of the corresponding
#			source code in return for reimbursement of the cost of
#			distribution.  This written offer must permit verbatim
#			duplication by anyone, or
#		C.	it is distributed by someone who received only the
#			executable form, and is accompanied by a copy of the
#			written offer of source code that they received concurrently.
#
#	In other words, you are welcome to use, share and improve this
#	source file.  You are forbidden to forbid anyone else to use, share
#	and improve what you give them.
#
#	The research leading to this tool is supported by the European Commission 
#	FP7 project "Energy-conscious 3D Server-on-Chip for Green Cloud Services 
#	(Project No:247779 "EuroCloud")".
#
#	Tool: http://www.cs.ucy.ac.cy/carch/xi/eetco.php
#	Project: http://www.eurocloudserver.com/
#	European Commission FP7: http://cordis.europa.eu/fp7/home_en.html
#
##############################################################################

use strict;

use lib "./packages/";
use resource;
use dc;

###########################################################
#
#	check valid input
#
###########################################################
my $argv_size = scalar @ARGV;
if ($argv_size < 2)
{
	print "usage: ./cost-et.pl <dc config file> <resource config file> [resource config file]\n";
	exit(0);
}

###########################################################
#
#	create DC
#
###########################################################

my $dc=dc->new($ARGV[0]);

#create resources and add them to $dc
for(my $i=1;$i<$argv_size;$i++)
{
	my $resource=resource->new($ARGV[$i],$dc);
	$dc->addServerConfiguration($resource);
}

#print input parameters
$dc->print_param();

###########################################################
#
#	TCO estimation
#
###########################################################

$dc->TCOEstimation();
$dc->availabilityEstimation();
$dc->environmentalImpactEstimation();

#print result
$dc->print_results();



1;
